<?php
// $Id: feeds.inc,v 1.1.2.1.2.1 2006/11/08 13:26:44 zirafa Exp $
/**
 * @file
 * This file provides various XML feeds for audio media.
 */

/**
  * Return XML for podcast feed
  */
function audio_playlist_podcast_feed($items = array(), $metadata = array()) {
  // Metadata about this feed
  $output  = '<?xml version="1.0" encoding="UTF-8"?>' . " \n";
  $output .= '<rss xmlns:itunes="http://www.itunes.com/dtds/podcast-1.0.dtd" xmlns:content="http://purl.org/rss/1.0/modules/content/" xmlns:wfw="http://wellformedweb.org/CommentAPI/" xmlns:dc="http://purl.org/dc/elements/1.1/" version="2.0">' . " \n";
  $output .= "<channel> \n";
  $output .= "<ttl>60</ttl> \n";
  $output .= "<title>". $metadata['title'] ."</title> \n";
  $output .= "<link>". $metadata['link'] ."</link> \n";
  $output .= "<generator>". $metadata['generator'] ."</generator>";
  $output .= "<managingEditor>". $metadata['owner_email'] ." (". $metadata['owner'] .")</managingEditor>";
  $output .= "<pubDate>" . $metadata['created'] . "</pubDate> \n";
  $output .= "<language>". $metadata['language'] ."</language>"; 
  $output .= "<copyright>". $metadata['copyright'] ."</copyright>";
  $output .= "<itunes:explicit>". $metadata['explicit'] ."</itunes:explicit>";
  $output .= "<itunes:subtitle>". $metadata['subtitle'] ."</itunes:subtitle>";
  $output .= "<itunes:author>". $metadata['author'] ."</itunes:author>";
  $output .= "<itunes:summary>" . $metadata['summary'] . "</itunes:summary>";
  $output .= "<description>" . $metadata['description'] ."</description>";
  $output .= "<itunes:owner>";
  $output .= "<itunes:name>". $metadata['owner'] ."</itunes:name>";
  $output .= "<itunes:email>". $metadata['owner_email'] ."</itunes:email>";
  $output .= "</itunes:owner>";
  $output .= "<itunes:image href=\"". $metadata['image']['url'] ."\" />";
  $output .= "<image><url>". $metadata['image']['url'] ."</url><width>". $metadata['image']['width'] ."</width><height>". $metadata['image']['height'] ."</height></image>";

  if (is_array($metadata['categories'])) {
    foreach ($metadata['categories'] as $category) {
      $output .= "<itunes:category text=\" ". $category ."\"/>"; // </itunes:category> used for subcategories
      $output .= "<category>". $category ."</category>";  // RSS categories
    }
  }
  
  // Cycle through all the items in this feed
  foreach ($items as $item) {
      $output .= "<item> \n";
      $output .= "  <title>". $item['title'] ."</title> \n";
      $output .= "  <guid>". $item['guid'] ."</guid> \n";
      $output .= "  <link>". $item['link'] ."</link> \n";
      $output .= "  <itunes:author>". $item['author'] ."</itunes:author> \n";
      $output .= "  <itunes:subtitle>". $item['subtitle'] ."</itunes:subtitle> \n";
      $output .= "  <dc:creator>". $item['creator'] ."</dc:creator> \n";
      $output .= "  <content:encoded>". $item['content'] ."</content:encoded> \n";
      $output .= "  <description>". $item['description'] ."</description> \n";
      $output .= "  <comments>". $item['comments'] ."</comments>";
      $output .= "  <itunes:summary>". $item['summary'] ."</itunes:summary> \n";
      $output .= "  <enclosure url=\"". $item['enclosure']['url'] ."\" length=\"". $item['enclosure']['filesize'] ."\" type=\"". $item['enclosure']['filemime'] ."\" /> \n";
      $keywords = implode(", ", $item['keywords']);
      $output .= "<category>". $keywords ."</category>";
      $output .= "  <itunes:keywords>". $keywords ."</itunes:keywords> \n";
      $output .= "  <itunes:duration>". $item['duration'] ."</itunes:duration> \n";
      $output .= "  <pubDate>" . $item['created'] . "</pubDate> \n";
      $output .= "</item> \n";
  }
  $output .= "</channel> \n";
  $output .= "</rss> \n";
  drupal_set_header('Content-Type: text/xml; charset=UTF-8');
  print $output;
} 

/**
  * Return XML for M3U feed
  */
function audio_playlist_m3u_feed($items = array(), $metadata = array()) {
  $output = "#EXTM3U\r\n";
  foreach ($items as $item) {
      $output .= "#EXTINF:". $item['duration'] .",". $item['author'] ." - ". $item['title'] ."\r\n";
      $output .= $item['enclosure']['url'] ."\r\n";
  }
  drupal_set_header("Pragma: no-cache"); // HTTP/1.0
  drupal_set_header("Cache-Control: private"); // HTTP/1.1
  drupal_set_header("Content-Type: audio/mpegurl", TRUE);
  drupal_set_header("Content-Length: ".strlen($output)."", TRUE);
  drupal_set_header("Content-Disposition: attachment; filename=\"". $metadata['title'] .".m3u\"", TRUE);
  print $output;
}

/**
  * Return XML for PLS feed
  */
function audio_playlist_pls_feed($items = array(), $metadata = array()) {
  $output = "[playlist]\r\n";
  $i = 1;
  foreach ($items as $item) {
      $output .= "File$i=". $item['enclosure']['url'] ."\r\n";
      $output .= "Title$i=". $item['author'] ." - " . $item['title'] ."\r\n";
      $output .= "Length$i=". $item['duration'] ."\r\n";
      $i++;
  }
  $output .= "NumberOfEntries=".count($items)."\r\n";
  $output .= "Version=2\r\n";
  drupal_set_header("Pragma: no-cache"); // HTTP/1.0
  drupal_set_header("Cache-Control: private"); // HTTP/1.1
  drupal_set_header("Content-Type: audio/x-scpls", TRUE);
  drupal_set_header("Content-Length: ".strlen($output)."", TRUE);
  drupal_set_header("Content-Disposition: attachment; filename=\"". $metadata['title'] .".pls\"", TRUE);
  print $output;
}

/**
  * Return XML for XSPF feed
  */
function audio_playlist_xspf_feed($items = array(), $metadata = array()) {
	$output = '<?xml version="1.0" encoding="UTF-8"?>';
  $output .= '<playlist version="1" xmlns="http://xspf.org/ns/0/">';
  $output .= "<title>". $metadata['title'] ."</title>";
  $output .= "<annotation>". $metadata['author'] ."</annotation>";
  $output .= "<creator>". $metadata['author'] ."</creator>";
  $output .= "<info>". $metadata['link'] ."</info>";
  $output .= "<location>". $metadata['feed_url'] ."</location>";
  $output .= "<license>". $metadata['copyright'] ."</license>";
  $output .= '<trackList>';
  foreach ($items as $item) {  
      $output .= '<track>';
      $output .= "<location>". $item['enclosure']['url'] ."</location>";
      $output .= "<creator>". $item['author'] ."</creator>";
      $output .= "<album>". $item['album'] ."</album>";
      $output .= "<title>". $item['title'] ."</title>";
      $output .= "<annotation>". $item['author'] ." - ". $item['title'] ."</annotation>";
      $output .= "<duration>". $item['duration'] ."</duration>";
      $output .= "<image>". $item['image']['url'] ."</image>";
      $output .= "<info>". $item['link'] ."</info>";
      $output .= '</track>';
  }
  $output .= '  </trackList>';
  $output .= '</playlist>';  

  drupal_set_header('Content-Type: text/xml; charset=utf-8');
  print $output;
}
